==> jmb.tools-0.2.8.tar.gz: jmb.tools-0.2.8/jmb/tools/functions/functions.py <==
from __future__ import unicode_literals

import six
import subprocess

class ExecuteError(Exception):
    pass

def execute(cmd, stdin=None, stdout=False, stderr=False, **kw):
    """execute a cmd syncronously, return (ret_code, stdout, stderr)
    If each of stdin, stdout, strerr is a string open that file to
    write (or read) and return None in the returning tuple
    if it's a file id or None use it, otherwise use subprocess.PIPE

    If stdin ends with '|' it will be taken as input to pipe into process::

        execute('chroot', stdin='<root:my_new_passwd')


    If stdin starts with '>>' it will append to the file

    """

    ## INPUT
    subproc_input = None
    if isinstance(stdin, str):
        if not stdin.endswith('|'):   # it's a filename to open
            stdin = open(stdin, 'r')
        else:
            subproc_input = stdin[:-1]  # it's a string to pipe
            stdin = subprocess.PIPE

    ## OUT & ERR
    if stdout == False:
        stdout = subprocess.PIPE
    if stderr == False:
        stderr = subprocess.PIPE

    if isinstance(stdout, str):
        mode = 'w'
        if stdout.startswith('>>'):
            mode = 'a'
        stdout = stdout.replace('>', '')
        stdout = open(stdout, mode)
        ret_stdout = None

    if isinstance(stderr, str):
        mode = 'w'
        if stderr.startswith('>>'):
            mode = 'a'
        stderr = stderr.replace('>', '')
        stderr = open(stderr, mode)
        ret_stderr = None

    ## CMD
    if isinstance(cmd, six.text_type):
        cmd = cmd.split()

    ## exec...
    try:
        p = subprocess.Popen(cmd, stdin=stdin, stdout=stdout, stderr=stderr, **kw)
        (stdout, stderr) = p.communicate(input=subproc_input)
    except Exception as e:
        stderr = "%s: %s" % (type(e), e)
        return (e, stdout, stderr)

    return (p.returncode, stdout, stderr)

def execute0(cmd, **kwargs):
    """
    execute cmd using execte but check that ret_code is 0 and raise executeError if not

    Note: using shell=True generally leads to more usable error messages.
    """
    ret_code, out, err = execute(cmd, **kwargs)
    if ret_code:
        msg = "Error while executing %s." % cmd
        if err:
            msg += "\nError message was:\n%s" % err
        if out:
            msg += "\nOutput message was:\n%s" % out
        raise ExecuteError(msg)
    return ret_code, out, err

==> jmb.tools-0.4.tar.gz: jmb.tools-0.4/jmb/tools/functions/functions.py <==
from __future__ import unicode_literals

import six
import subprocess

class ExecuteError(Exception):
    pass

def execute(cmd, stdin=None, stdout=False, stderr=False, **kw):
    """execute a cmd syncronously, return (ret_code, stdout, stderr)
    If each of stdin, stdout, strerr is a string open that file to
    write (or read) and return None in the returning tuple
    if it's a file id or None use it, otherwise use subprocess.PIPE

    If stdin ends with '|' it will be taken as input to pipe into process::

        execute('chroot', stdin='<root:my_new_passwd')


    If stdin starts with '>>' it will append to the file

    """

    ## INPUT
    subproc_input = None
    if isinstance(stdin, str):
        if not stdin.endswith('|'):   # it's a filename to open
            stdin = open(stdin, 'r')
        else:
            subproc_input = stdin[:-1]  # it's a string to pipe
            stdin = subprocess.PIPE

    ## OUT & ERR
    if stdout == False:
        stdout = subprocess.PIPE
    if stderr == False:
        stderr = subprocess.PIPE

    if isinstance(stdout, str):
        mode = 'w'
        if stdout.startswith('>>'):
            mode = 'a'
        stdout = stdout.replace('>', '')
        stdout = open(stdout, mode)
        ret_stdout = None

    if isinstance(stderr, str):
        mode = 'w'
        if stderr.startswith('>>'):
            mode = 'a'
        stderr = stderr.replace('>', '')
        stderr = open(stderr, mode)
        ret_stderr = None

    ## CMD
    if isinstance(cmd, six.string_types):
        cmd = cmd.split()

    ## exec...
    try:
        p = subprocess.Popen(cmd, stdin=stdin, stdout=stdout, stderr=stderr, **kw)
        (stdout, stderr) = p.communicate(input=subproc_input)
    except Exception as e:
        stderr = "%s: %s" % (type(e), e)
        return (e, stdout, stderr)

    return (p.returncode, stdout, stderr)

def execute0(cmd, **kwargs):
    """
    execute cmd using execte but check that ret_code is 0 and raise executeError if not

    Note: using shell=True generally leads to more usable error messages.
    """
    ret_code, out, err = execute(cmd, **kwargs)
    if ret_code:
        msg = "Error while executing %s." % cmd
        if err:
            msg += "\nError message was:\n%s" % err
        if out:
            msg += "\nOutput message was:\n%s" % out
        raise ExecuteError(msg)
    return ret_code, out, err
